import { formatPrice } from '../../../utils/util';

// pages/components/PayTypeChart/PayTypeChart.js
let paytypeChart = null;
let month = '';
const colorMap = {
  aimi: '#EB7E59',
  bean: '#13C2C2',
  discount: '#FACC14',
  online: '#1890FF',
};

function initChart(canvas, width, height, F2) {
  const data = [];
  paytypeChart = new F2.Chart({
    el: canvas,
    width,
    height,
  });

  paytypeChart.source(data, {
    days: {
      min: 1,
      max: 31,
    },
  });
  paytypeChart.tooltip({
    showItemMarker: false,
    background: {
      radius: 2,
      fill: '#f166fd',
      padding: [6, 10],
    },
    onShow(ev) {
      const { items } = ev;
      items[0].name = '';
      items[0].value = month + '-' + items[0].title;
      items[1].name = '';
      items[1].value = items[1].value + '元';
    },
  });
  paytypeChart.coord('polar', {
    transposed: true,
    innerRadius: 0.5,
    radius: 0.9,
  });
  paytypeChart.legend({
    position: 'right',
    marker: 'square',
  });
  paytypeChart.tooltip(false);
  paytypeChart
    .interval()
    .position('a*count')
    .color('key', ['#EB7E59', '#13C2C2', '#FACC14', '#1890FF'])
    .adjust('stack');
  paytypeChart.axis(false);
  paytypeChart.render();
  return paytypeChart;
}

Component({
  properties: {
    dataList: {
      type: Array,
      value: [],
      observer(newVal) {
        paytypeChart &&
          paytypeChart.legend({
            position: 'right',
            marker: 'square',
            itemFormatter: val => {
              let item = newVal.find(item => item.key === val);
              return item ? item.name + '    ' + formatPrice(item.count) : '';
            },
            // custom: true,
            // items: newVal.map(item => ({
            //   name: item.name,
            //   value: ' ' + formatPrice(item.count),
            //   marker: {
            //     symbol: 'square',
            //     fill: colorMap[item.key],
            //     radius: 4,
            //   },
            // })),
          });
        paytypeChart && paytypeChart.changeData(newVal);
      },
    },
    month: {
      type: String,
      value: '',
      observer(newVal) {
        month = newVal;
      },
    },
  },
  data: {
    opts: {
      onInit: initChart,
    },
  },
});
